Learn R Programming

gtexLite (version 0.1.13)

gtexLite-package: gtexLite

Description

gtexLite

Arguments

Details

The DESCRIPTION file: gtexLite gtexLite

gtexPack package provides a lossless, indexed, compressed, sharded GRanges representation of all cis eqtl results published in GTEx v4. gtexLite is an excerpt of three tissues with loci limited to 500kb radius around genes on 17q12 or in reactome PI3K-AKT signaling in cancer pathway.

See Also

gQTLBase package defines key infrastructure for the index.